@@ -1,6 +1,9 @@
 min.np<-function (fdataobj, h =NULL, W = diag(1, nrow = np, ncol = np), Ker = Ker.norm,type.CV = GCV.S,type.S=S.NW,par.CV=list(trim=0,draw=FALSE),...)
 {
-if (!is.fdata(fdataobj)) fdataobj=fdata(fdataobj)
+ if (!is.fdata(fdataobj)) fdataobj=fdata(fdataobj)
+  nas1<-apply(fdataobj$data,1,count.na)
+ if (any(nas1))  stop("fdataobj contain ",sum(nas1)," curves with some NA value \n")
+
 x<-fdataobj[["data"]]
 tt<-fdataobj[["argvals"]]
 rtt<-fdataobj[["rangeval"]]
